CsgLeafNode

Struct CsgLeafNode 

pub struct CsgLeafNode {
    pub p_impl: Arc<ManifoldImpl>,
    pub transform: Mat3x4,
}

Fields

p_impl: Arc<ManifoldImpl>transform: Mat3x4

Implementations

Source

impl CsgLeafNode

pub fn new(mesh: ManifoldImpl) -> Self

Create a leaf from a mesh with identity transform.

pub fn with_transform(mesh: ManifoldImpl, transform: Mat3x4) -> Self

Create a leaf from a mesh with a specific transform.

pub fn empty() -> Self

Create an empty leaf.

pub fn get_impl(&self) -> ManifoldImpl

Get the mesh, applying the lazy transform if needed. Port of C++ CsgLeafNode::GetImpl()

pub fn apply_transform(&self, m: Mat3x4) -> Self

Return a new leaf with composed transform. Port of C++ CsgLeafNode::Transform()

pub fn get_bounding_box(&self) -> BBox

Get bounding box without materializing the full mesh. Uses Arvo’s algorithm for AABB transform. Port of C++ CsgLeafNode::GetBoundingBox()

pub fn num_vert(&self) -> usize

Vertex count without triggering transform.