Module types

Module types 

Structs

Barycentric
Box
ExecutionParams
Halfedge
MeshGLP
GL-style mesh representation. Generic over precision (f32/f64) and index type (u32/u64).
MeshRelationD
Mesh relation table stored on ManifoldImpl.
PolyVert
Polygon vertex with index.
Quality
RayHit
Result of a RayCast query: a single triangle-ray intersection.
Rect
Relation
Transform relation between meshes.
Smoothness
TmpEdge
TriRef

Enums

Error
OpType

Constants

DEFAULT_ANGLE
DEFAULT_LENGTH
DEFAULT_SEGMENTS
K_HALF_PI
K_PI
K_PRECISION
Precision used for epsilon calculations relative to bounding-box scale.
K_TWO_PI

Functions

cosd
Cosine function where multiples of 90 degrees come out exact.
degrees
next3
Return next index within 0..3 (wraps 0→1→2→0).
next_halfedge
Return next halfedge index within the same triangle (wraps 0→1→2→0).
prev_halfedge
Returns the previous halfedge index within the same triangle. For triangle t: PrevHalfedge(3t+i) = 3t + (i+2)%3
radians
sind
Sine function where multiples of 90 degrees come out exact.
smoothstep
Smooth Hermite interpolation between 0 and 1 when edge0 < x < edge1.

Type Aliases

MeshGL
Single-precision mesh (standard for graphics).
MeshGL64
Double-precision, 64-bit index mesh (for huge meshes).
Polygons
Set of polygons with holes (arbitrary nesting).
PolygonsIdx
Set of indexed polygons with holes.
SimplePolygon
Single polygon contour, wound CCW. First and last point are implicitly connected.
SimplePolygonIdx
Single indexed polygon contour, wound CCW.