Skip to main contentModule constructors
Source - cylinder
- Constructs a cylinder (or frustum/cone) by extruding a circle polygon.
- extrude
- Extrudes a set of polygons along the Z axis.
- revolve
- Constructs a manifold by revolving polygons around the Y axis (becomes Z).