pub struct CsgLeafNode {
pub p_impl: Arc<ManifoldImpl>,
pub transform: Mat3x4,
}Fields
p_impl: Arc<ManifoldImpl>transform: Mat3x4Implementations
Sourceimpl CsgLeafNode
impl CsgLeafNode
Sourcepub fn new(mesh: ManifoldImpl) -> Self
pub fn new(mesh: ManifoldImpl) -> Self
Create a leaf from a mesh with identity transform.
Sourcepub fn with_transform(mesh: ManifoldImpl, transform: Mat3x4) -> Self
pub fn with_transform(mesh: ManifoldImpl, transform: Mat3x4) -> Self
Create a leaf from a mesh with a specific transform.
Sourcepub fn get_impl(&self) -> ManifoldImpl
pub fn get_impl(&self) -> ManifoldImpl
Get the mesh, applying the lazy transform if needed. Port of C++ CsgLeafNode::GetImpl()
Sourcepub fn apply_transform(&self, m: Mat3x4) -> Self
pub fn apply_transform(&self, m: Mat3x4) -> Self
Return a new leaf with composed transform. Port of C++ CsgLeafNode::Transform()
Sourcepub fn get_bounding_box(&self) -> BBox
pub fn get_bounding_box(&self) -> BBox
Get bounding box without materializing the full mesh. Uses Arvo’s algorithm for AABB transform. Port of C++ CsgLeafNode::GetBoundingBox()